@@ -7,9 +7,9 @@ from typing import Dict, List, Text
 try:
     import allure
 
-    USE_ALLURE = True
+    ALLURE = allure
 except ModuleNotFoundError:
-    USE_ALLURE = False
+    ALLURE = None
 
 from loguru import logger
 
@@ -27,7 +27,7 @@ from httprunner.models import (
     VariablesMapping,
 )
 from httprunner.parser import Parser
-from httprunner.utils import LOGGER_FORMAT, init_logger, merge_variables
+from httprunner.utils import LOGGER_FORMAT, merge_variables
 
 
 class SessionRunner(object):
@@ -46,6 +46,7 @@ class SessionRunner(object):
     __export: List[Text] = []
     __step_results: List[StepResult] = []
     __session_variables: VariablesMapping = {}
+    __is_reference: bool = False
     # time
     __start_at: float = 0
     __duration: float = 0
@@ -53,11 +54,11 @@ class SessionRunner(object):
     __log_path: Text = ""
 
     def __init(self):
-        init_logger()
         self.__config = self.config.struct()
-        self.__session_variables = {}
+        self.__session_variables = self.__session_variables or {}
         self.__start_at = 0
         self.__duration = 0
+        self.__is_reference = self.__is_reference or False
 
         self.__project_meta = self.__project_meta or load_project_meta(
             self.__config.path
@@ -77,6 +78,10 @@ class SessionRunner(object):
     def get_config(self) -> TConfig:
         return self.__config
 
+    def set_references(self) -> "SessionRunner":
+        self.__is_reference = True
+        return self
+
     def with_case_id(self, case_id: Text) -> "SessionRunner":
         self.case_id = case_id
         return self
@@ -178,8 +183,8 @@ class SessionRunner(object):
         # run step
         for i in range(step.retry_times + 1):
             try:
-                if USE_ALLURE:
-                    with allure.step(f"step: {step.name()}"):
+                if ALLURE is not None:
+                    with ALLURE.step(f"step: {step.name()}"):
                         step_result: StepResult = step.run(self)
                 else:
                     step_result: StepResult = step.run(self)
@@ -193,7 +198,7 @@ class SessionRunner(object):
                     )
                     time.sleep(step.retry_interval)
                     logger.info(
-                        f"run step retry ({i+1}/{step.retry_times} time): {step.name()} >>>>>>"
+                        f"run step retry ({i + 1}/{step.retry_times} time): {step.name()} >>>>>>"
                     )
 
         # save extracted variables to session variables
@@ -209,10 +214,10 @@ class SessionRunner(object):
         self.__init()
         self.__parse_config(param)
 
-        if USE_ALLURE:
+        if ALLURE is not None and not self.__is_reference:
             # update allure report meta
-            allure.dynamic.title(self.__config.name)
-            allure.dynamic.description(f"TestCase ID: {self.case_id}")
+            ALLURE.dynamic.title(self.__config.name)
+            ALLURE.dynamic.description(f"TestCase ID: {self.case_id}")
 
         logger.info(
             f"Start to run testcase: {self.__config.name}, TestCase ID: {self.case_id}"
@@ -226,13 +231,17 @@ class SessionRunner(object):
                 self.__run_step(step)
         finally:
             logger.info(f"generate testcase log: {self.__log_path}")
-            if USE_ALLURE:
-                allure.attach.file(self.__log_path, name='all log', attachment_type=allure.attachment_type.TEXT)
+            if ALLURE is not None:
+                ALLURE.attach.file(
+                    self.__log_path,
+                    name="all log",
+                    attachment_type=ALLURE.attachment_type.TEXT,
+                )
 
         self.__duration = time.time() - self.__start_at
         return self
 
 
 class HttpRunner(SessionRunner):
-    # split SessionRunner to keep consistant with golang version
+    # split SessionRunner to keep consistent with golang version
     pass
