@@ -1,7 +1,8 @@
-import copy
+import json
 import time
 from typing import Any, Dict, List, Text, Union
 
+import requests
 from loguru import logger
 
 from httprunner import utils
@@ -18,7 +19,7 @@ from httprunner.models import (
 )
 from httprunner.parser import build_url
 from httprunner.response import ResponseObject
-from httprunner.runner import HttpRunner, USE_ALLURE
+from httprunner.runner import ALLURE, HttpRunner
 
 
 def call_hooks(
@@ -66,6 +67,16 @@ def call_hooks(
             logger.error(f"Invalid hook format: {hook}")
 
 
+def pretty_format(v) -> str:
+    if isinstance(v, dict):
+        return json.dumps(v, indent=4, ensure_ascii=False)
+
+    if isinstance(v, requests.structures.CaseInsensitiveDict):
+        return json.dumps(dict(v.items()), indent=4, ensure_ascii=False)
+
+    return repr(utils.omit_long_data(v))
+
+
 def run_step_request(runner: HttpRunner, step: TStep) -> StepResult:
     """run teststep: request"""
     step_result = StepResult(
@@ -82,10 +93,17 @@ def run_step_request(runner: HttpRunner, step: TStep) -> StepResult:
     request_dict = step.request.dict()
     request_dict.pop("upload", None)
     parsed_request_dict = runner.parser.parse_data(request_dict, step_variables)
-    parsed_request_dict["headers"].setdefault(
-        "HRUN-Request-ID",
-        f"HRUN-{runner.case_id}-{str(int(time.time() * 1000))[-6:]}",
-    )
+
+    request_headers = parsed_request_dict.pop("headers", {})
+    # omit pseudo header names for HTTP/1, e.g. :authority, :method, :path, :scheme
+    request_headers = {
+        key: request_headers[key] for key in request_headers if not key.startswith(":")
+    }
+    request_headers[
+        "HRUN-Request-ID"
+    ] = f"HRUN-{runner.case_id}-{str(int(time.time() * 1000))[-6:]}"
+    parsed_request_dict["headers"] = request_headers
+
     step_variables["request"] = parsed_request_dict
 
     # setup hooks
@@ -104,28 +122,36 @@ def run_step_request(runner: HttpRunner, step: TStep) -> StepResult:
     request_print = "====== request details ======\n"
     request_print += f"url: {url}\n"
     request_print += f"method: {method}\n"
-    headers = parsed_request_dict.get("headers", {})
-    request_print += f"headers: {headers}\n"
     for k, v in parsed_request_dict.items():
-        v = utils.omit_long_data(v)
-        request_print += f"{k}: {repr(v)}\n"
-    request_print += "\n"
+        request_print += f"{k}: {pretty_format(v)}\n"
 
-    # request
-    if USE_ALLURE:
-        import allure
-        allure.attach(request_print, name="request details", attachment_type=allure.attachment_type.TEXT)
+    logger.debug(request_print)
+    if ALLURE is not None:
+        ALLURE.attach(
+            request_print,
+            name="request details",
+            attachment_type=ALLURE.attachment_type.TEXT,
+        )
     resp = runner.session.request(method, url, **parsed_request_dict)
 
     # log response
     response_print = "====== response details ======\n"
     response_print += f"status_code: {resp.status_code}\n"
-    response_print += f"headers: {resp.headers}\n"
-    response_print += f"body: {repr(resp.text)}\n"
+    response_print += f"headers: {pretty_format(resp.headers)}\n"
 
-    if USE_ALLURE:
-        import allure
-        allure.attach(response_print, name="response details", attachment_type=allure.attachment_type.TEXT)
+    try:
+        resp_body = resp.json()
+    except (requests.exceptions.JSONDecodeError, json.decoder.JSONDecodeError):
+        resp_body = resp.content
+
+    response_print += f"body: {pretty_format(resp_body)}\n"
+    logger.debug(response_print)
+    if ALLURE is not None:
+        ALLURE.attach(
+            response_print,
+            name="response details",
+            attachment_type=ALLURE.attachment_type.TEXT,
+        )
     resp_obj = ResponseObject(resp, runner.parser)
     step_variables["response"] = resp_obj
 
@@ -133,11 +159,6 @@ def run_step_request(runner: HttpRunner, step: TStep) -> StepResult:
     if step.teardown_hooks:
         call_hooks(runner, step.teardown_hooks, step_variables, "teardown request")
 
-    def log_req_resp_details():
-        err_msg = "\n{} DETAILED REQUEST & RESPONSE {}\n".format("*" * 32, "*" * 32)
-        err_msg += request_print + response_print
-        logger.error(err_msg)
-
     # extract
     extractors = step.extract
     extract_mapping = resp_obj.extract(extractors, step_variables)
@@ -152,7 +173,6 @@ def run_step_request(runner: HttpRunner, step: TStep) -> StepResult:
         resp_obj.validate(validators, variables_mapping)
         step_result.success = True
     except ValidationFailure:
-        log_req_resp_details()
         raise
     finally:
         session_data = runner.session.data
