@@ -2,15 +2,14 @@
 import sys
 import time
 from typing import Text
+
 from loguru import logger
 
 from httprunner import utils
-from httprunner.exceptions import SqlMethodNotSupport
-from httprunner.exceptions import ValidationFailure
-from httprunner.models import IStep, StepResult, TStep
-from httprunner.models import SqlMethodEnum, TSqlRequest
+from httprunner.exceptions import SqlMethodNotSupport, ValidationFailure
+from httprunner.models import IStep, SqlMethodEnum, StepResult, TSqlRequest, TStep
 from httprunner.response import SqlResponseObject
-from httprunner.runner import HttpRunner, USE_ALLURE
+from httprunner.runner import ALLURE, HttpRunner
 from httprunner.step_request import (
     StepRequestExtraction,
     StepRequestValidation,
@@ -18,8 +17,8 @@ from httprunner.step_request import (
 )
 
 try:
-    import sqlalchemy
     import pymysql
+    import sqlalchemy
 
     SQL_READY = True
 except ModuleNotFoundError:
@@ -103,9 +102,12 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
 
     sql_request_print += "\n"
 
-    if USE_ALLURE:
-        import allure
-        allure.attach(sql_request_print, name="sql request details", attachment_type=allure.attachment_type.TEXT)
+    if ALLURE is not None:
+        ALLURE.attach(
+            sql_request_print,
+            name="sql request details",
+            attachment_type=ALLURE.attachment_type.TEXT,
+        )
     logger.info(f"Executing SQL: {parsed_request_dict['sql']}")
     if step.sql_request.method == SqlMethodEnum.FETCHONE:
         sql_resp = runner.db_engine.fetchone(parsed_request_dict["sql"])
@@ -125,15 +127,29 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
         raise SqlMethodNotSupport(
             f"step.sql_request.method {parsed_request_dict['method']} not support"
         )
+
     # log response
     sql_response_print = "====== sql response details ======\n"
-    for k, v in sql_resp.items():
-        v = utils.omit_long_data(v)
-        sql_response_print += f"{k}: {repr(v)}\n"
-
-    if USE_ALLURE:
-        import allure
-        allure.attach(sql_request_print, name="sql response details", attachment_type=allure.attachment_type.TEXT)
+    if isinstance(sql_resp, dict):
+        for k, v in sql_resp.items():
+            v = utils.omit_long_data(v)
+            sql_response_print += f"{k}: {repr(v)}\n"
+    elif isinstance(sql_resp, list):
+        sql_response_print += f"count: {len(sql_resp)}\n"
+        sql_response_print += "-" * 34 + "\n"
+        for el in sql_resp:
+            for k, v in el.items():
+                v = utils.omit_long_data(v)
+                sql_response_print += f"{k}: {repr(v)}\n"
+            sql_response_print += "-" * 34 + "\n"
+    elif sql_resp is None:
+        sql_response_print += "None\n"
+    if ALLURE is not None:
+        ALLURE.attach(
+            sql_response_print,
+            name="sql response details",
+            attachment_type=ALLURE.attachment_type.TEXT,
+        )
 
     resp_obj = SqlResponseObject(sql_resp, parser=runner.parser)
     step_variables["sql_response"] = resp_obj
